DnsBench - Multi-Thread Python Application for Dns Benchmark

# DnsBench

Multi-Threaded Python Application for Dns Benchmark

### Start

- Disable Cache

- Enable DoH

- Enable DoT

#### DNS Benchmark

All Resolving Speed are measured in ms (millisecond)

####

- Here is a list of known DNS providers to choose from.
- This Application checks over 55+ public DNS server and finds the best and optimistic server for your network. NOTE: Currently this only used ipv4 and some get be blocked by your ISP.